==> western-world-3.0.546.tgz: package/src/defs/clouds_63/clouds_63.js <==
const style = require('!!css-loader!sass-loader!./clouds_63.scss').default;

export const clouds_63 = `
<symbol id="clouds_63" viewBox="0 0 8192 8192">
<style>
	.clouds-white{fill:white;}
	${style}
</style>
<g id="clouds_layer_1">
	<path class="clouds-white" d="M5673.3,2254.1c0,0,22-214.6,242.2-214.6c220.1,0,242.2,176.1,242.2,176.1s187.1-38.5,236.7,99.1
		c49.5,137.6-66,220.1-66,220.1s-66,27.5-159.6,27.5s-605.4,0-605.4,0s-132.1-22-132.1-143.1s99.1-165.1,99.1-165.1
		S5601.7,2226.6,5673.3,2254.1z"/>
	<path class="clouds-white" d="M7045.4,854.2c0,0,25-243.7,275-243.7c250,0,275,200,275,200s212.5-43.7,268.7,112.5
		c56.2,156.2-75,250-75,250s-75,31.2-181.2,31.2c-106.2,0-687.5,0-687.5,0s-150-25-150-162.5s112.5-187.5,112.5-187.5
		S6964.2,823,7045.4,854.2z"/>
	<path class="clouds-white" d="M606.4,1941.7c0,0,23.5-229.6,259-229.6s259,188.4,259,188.4s200.1-41.2,253.1,106s-70.6,235.5-70.6,235.5
		s-70.6,29.4-170.7,29.4s-647.5,0-647.5,0s-141.3-23.5-141.3-153.1s106-176.6,106-176.6S529.9,1912.2,606.4,1941.7z"/>
	<path class="clouds-white" d="M2688.6,1060.9c0,0,22.8-221.9,250.4-221.9c227.6,0,250.4,182.1,250.4,182.1s193.5-39.8,244.7,102.4
		s-68.3,227.6-68.3,227.6s-68.3,28.4-165,28.4s-625.9,0-625.9,0s-136.6-22.8-136.6-147.9s102.4-170.7,102.4-170.7
		S2614.6,1032.4,2688.6,1060.9z"/>
</g>
<g id="clouds_layer_2">
	<path class="clouds-white" d="M5673.3,2254.1c0,0,22-214.6,242.2-214.6c220.1,0,242.2,176.1,242.2,176.1s187.1-38.5,236.7,99.1
		c49.5,137.6-66,220.1-66,220.1s-66,27.5-159.6,27.5s-605.4,0-605.4,0s-132.1-22-132.1-143.1s99.1-165.1,99.1-165.1
		S5601.7,2226.6,5673.3,2254.1z"/>
	<path class="clouds-white" d="M7045.4,854.2c0,0,25-243.7,275-243.7c250,0,275,200,275,200s212.5-43.7,268.7,112.5
		c56.2,156.2-75,250-75,250s-75,31.2-181.2,31.2c-106.2,0-687.5,0-687.5,0s-150-25-150-162.5s112.5-187.5,112.5-187.5
		S6964.2,823,7045.4,854.2z"/>
	<path class="clouds-white" d="M606.4,1941.7c0,0,23.5-229.6,259-229.6s259,188.4,259,188.4s200.1-41.2,253.1,106s-70.6,235.5-70.6,235.5
		s-70.6,29.4-170.7,29.4s-647.5,0-647.5,0s-141.3-23.5-141.3-153.1s106-176.6,106-176.6S529.9,1912.2,606.4,1941.7z"/>
	<path class="clouds-white" d="M2688.6,1060.9c0,0,22.8-221.9,250.4-221.9c227.6,0,250.4,182.1,250.4,182.1s193.5-39.8,244.7,102.4
		s-68.3,227.6-68.3,227.6s-68.3,28.4-165,28.4s-625.9,0-625.9,0s-136.6-22.8-136.6-147.9s102.4-170.7,102.4-170.7
		S2614.6,1032.4,2688.6,1060.9z"/>
</g>
<circle class="st27" cx="6775.6" cy="1379.5" r="604.6"/>
<g id="clouds_layer_3">
	<path class="clouds-white" d="M7102.4,2350.9c0,0,30.2-311.4,332-311.4c301.8,0,332,255.5,332,255.5s256.5-55.9,324.4,143.7
		c67.9,199.6-90.5,319.4-90.5,319.4s-90.5,39.9-218.8,39.9c-128.3,0-829.9,0-829.9,0s-181.1-31.9-181.1-207.6
		c0-175.7,135.8-239.6,135.8-239.6S7004.3,2311,7102.4,2350.9z"/>
	<path class="clouds-white" d="M5621,1423.4c0,0,30.8-323.1,338.8-323.1s338.8,265.1,338.8,265.1s261.8-58,331.1,149.1
		s-92.4,331.4-92.4,331.4s-92.4,41.4-223.3,41.4c-130.9,0-847.1,0-847.1,0s-184.8-33.1-184.8-215.4s138.6-248.6,138.6-248.6
		S5520.9,1382,5621,1423.4z"/>
	<path class="clouds-white" d="M835.6,940.9c0,0,32.9-305.5,362-305.5s362,250.6,362,250.6s279.7-54.8,353.7,141
		c74,195.8-98.7,313.3-98.7,313.3s-98.7,39.2-238.6,39.2s-904.9,0-904.9,0s-197.4-31.3-197.4-203.6s148.1-235,148.1-235
		S728.7,901.7,835.6,940.9z"/>
	<path class="clouds-white" d="M3486.2,1813c0,0,31.2-319.2,342.8-319.2s342.8,261.9,342.8,261.9s264.9-57.3,335,147.3
		c70.1,204.6-93.5,327.4-93.5,327.4s-93.5,40.9-225.9,40.9c-132.4,0-857,0-857,0s-187-32.7-187-212.8s140.2-245.5,140.2-245.5
		S3384.9,1772.1,3486.2,1813z"/>
</g>
<g id="clouds_layer_4">
	<path class="clouds-white" d="M7102.4,2350.9c0,0,30.2-311.4,332-311.4c301.8,0,332,255.5,332,255.5s256.5-55.9,324.4,143.7
		c67.9,199.6-90.5,319.4-90.5,319.4s-90.5,39.9-218.8,39.9c-128.3,0-829.9,0-829.9,0s-181.1-31.9-181.1-207.6
		c0-175.7,135.8-239.6,135.8-239.6S7004.3,2311,7102.4,2350.9z"/>
	<path class="clouds-white" d="M5621,1423.4c0,0,30.8-323.1,338.8-323.1s338.8,265.1,338.8,265.1s261.8-58,331.1,149.1
		s-92.4,331.4-92.4,331.4s-92.4,41.4-223.3,41.4c-130.9,0-847.1,0-847.1,0s-184.8-33.1-184.8-215.4s138.6-248.6,138.6-248.6
		S5520.9,1382,5621,1423.4z"/>
	<path class="clouds-white" d="M835.6,940.9c0,0,32.9-305.5,362-305.5s362,250.6,362,250.6s279.7-54.8,353.7,141
		c74,195.8-98.7,313.3-98.7,313.3s-98.7,39.2-238.6,39.2s-904.9,0-904.9,0s-197.4-31.3-197.4-203.6s148.1-235,148.1-235
		S728.7,901.7,835.6,940.9z"/>
	<path class="clouds-white" d="M3486.2,1813c0,0,31.2-319.2,342.8-319.2s342.8,261.9,342.8,261.9s264.9-57.3,335,147.3
		c70.1,204.6-93.5,327.4-93.5,327.4s-93.5,40.9-225.9,40.9c-132.4,0-857,0-857,0s-187-32.7-187-212.8s140.2-245.5,140.2-245.5
		S3384.9,1772.1,3486.2,1813z"/>
</g>
</symbol>

`;

==> western-world-3.0.629.tgz: package/src/defs/clouds_63/clouds_63.js <==
const style = require('!!css-loader!sass-loader!./clouds_63.scss').default;

export const clouds_63 = `
<symbol id="clouds_63" viewBox="0 0 8192 8192">
<style>
	.clouds-white{fill:white;}
	.sun{fill:#FCBC52}
	${style}
</style>
<g id="clouds_layer_1">
	<path class="clouds-white" d="M5673.3,2254.1c0,0,22-214.6,242.2-214.6c220.1,0,242.2,176.1,242.2,176.1s187.1-38.5,236.7,99.1
		c49.5,137.6-66,220.1-66,220.1s-66,27.5-159.6,27.5s-605.4,0-605.4,0s-132.1-22-132.1-143.1s99.1-165.1,99.1-165.1
		S5601.7,2226.6,5673.3,2254.1z"/>
	<path class="clouds-white" d="M7045.4,854.2c0,0,25-243.7,275-243.7c250,0,275,200,275,200s212.5-43.7,268.7,112.5
		c56.2,156.2-75,250-75,250s-75,31.2-181.2,31.2c-106.2,0-687.5,0-687.5,0s-150-25-150-162.5s112.5-187.5,112.5-187.5
		S6964.2,823,7045.4,854.2z"/>
	<path class="clouds-white" d="M606.4,1941.7c0,0,23.5-229.6,259-229.6s259,188.4,259,188.4s200.1-41.2,253.1,106s-70.6,235.5-70.6,235.5
		s-70.6,29.4-170.7,29.4s-647.5,0-647.5,0s-141.3-23.5-141.3-153.1s106-176.6,106-176.6S529.9,1912.2,606.4,1941.7z"/>
	<path class="clouds-white" d="M2688.6,1060.9c0,0,22.8-221.9,250.4-221.9c227.6,0,250.4,182.1,250.4,182.1s193.5-39.8,244.7,102.4
		s-68.3,227.6-68.3,227.6s-68.3,28.4-165,28.4s-625.9,0-625.9,0s-136.6-22.8-136.6-147.9s102.4-170.7,102.4-170.7
		S2614.6,1032.4,2688.6,1060.9z"/>
</g>
<g id="clouds_layer_2">
	<path class="clouds-white" d="M5673.3,2254.1c0,0,22-214.6,242.2-214.6c220.1,0,242.2,176.1,242.2,176.1s187.1-38.5,236.7,99.1
		c49.5,137.6-66,220.1-66,220.1s-66,27.5-159.6,27.5s-605.4,0-605.4,0s-132.1-22-132.1-143.1s99.1-165.1,99.1-165.1
		S5601.7,2226.6,5673.3,2254.1z"/>
	<path class="clouds-white" d="M7045.4,854.2c0,0,25-243.7,275-243.7c250,0,275,200,275,200s212.5-43.7,268.7,112.5
		c56.2,156.2-75,250-75,250s-75,31.2-181.2,31.2c-106.2,0-687.5,0-687.5,0s-150-25-150-162.5s112.5-187.5,112.5-187.5
		S6964.2,823,7045.4,854.2z"/>
	<path class="clouds-white" d="M606.4,1941.7c0,0,23.5-229.6,259-229.6s259,188.4,259,188.4s200.1-41.2,253.1,106s-70.6,235.5-70.6,235.5
		s-70.6,29.4-170.7,29.4s-647.5,0-647.5,0s-141.3-23.5-141.3-153.1s106-176.6,106-176.6S529.9,1912.2,606.4,1941.7z"/>
	<path class="clouds-white" d="M2688.6,1060.9c0,0,22.8-221.9,250.4-221.9c227.6,0,250.4,182.1,250.4,182.1s193.5-39.8,244.7,102.4
		s-68.3,227.6-68.3,227.6s-68.3,28.4-165,28.4s-625.9,0-625.9,0s-136.6-22.8-136.6-147.9s102.4-170.7,102.4-170.7
		S2614.6,1032.4,2688.6,1060.9z"/>
</g>
<circle class="sun" cx="6775.6" cy="1379.5" r="604.6"/>
<g id="clouds_layer_3">
	<path class="clouds-white" d="M7102.4,2350.9c0,0,30.2-311.4,332-311.4c301.8,0,332,255.5,332,255.5s256.5-55.9,324.4,143.7
		c67.9,199.6-90.5,319.4-90.5,319.4s-90.5,39.9-218.8,39.9c-128.3,0-829.9,0-829.9,0s-181.1-31.9-181.1-207.6
		c0-175.7,135.8-239.6,135.8-239.6S7004.3,2311,7102.4,2350.9z"/>
	<path class="clouds-white" d="M5621,1423.4c0,0,30.8-323.1,338.8-323.1s338.8,265.1,338.8,265.1s261.8-58,331.1,149.1
		s-92.4,331.4-92.4,331.4s-92.4,41.4-223.3,41.4c-130.9,0-847.1,0-847.1,0s-184.8-33.1-184.8-215.4s138.6-248.6,138.6-248.6
		S5520.9,1382,5621,1423.4z"/>
	<path class="clouds-white" d="M835.6,940.9c0,0,32.9-305.5,362-305.5s362,250.6,362,250.6s279.7-54.8,353.7,141
		c74,195.8-98.7,313.3-98.7,313.3s-98.7,39.2-238.6,39.2s-904.9,0-904.9,0s-197.4-31.3-197.4-203.6s148.1-235,148.1-235
		S728.7,901.7,835.6,940.9z"/>
	<path class="clouds-white" d="M3486.2,1813c0,0,31.2-319.2,342.8-319.2s342.8,261.9,342.8,261.9s264.9-57.3,335,147.3
		c70.1,204.6-93.5,327.4-93.5,327.4s-93.5,40.9-225.9,40.9c-132.4,0-857,0-857,0s-187-32.7-187-212.8s140.2-245.5,140.2-245.5
		S3384.9,1772.1,3486.2,1813z"/>
</g>
<g id="clouds_layer_4">
	<path class="clouds-white" d="M7102.4,2350.9c0,0,30.2-311.4,332-311.4c301.8,0,332,255.5,332,255.5s256.5-55.9,324.4,143.7
		c67.9,199.6-90.5,319.4-90.5,319.4s-90.5,39.9-218.8,39.9c-128.3,0-829.9,0-829.9,0s-181.1-31.9-181.1-207.6
		c0-175.7,135.8-239.6,135.8-239.6S7004.3,2311,7102.4,2350.9z"/>
	<path class="clouds-white" d="M5621,1423.4c0,0,30.8-323.1,338.8-323.1s338.8,265.1,338.8,265.1s261.8-58,331.1,149.1
		s-92.4,331.4-92.4,331.4s-92.4,41.4-223.3,41.4c-130.9,0-847.1,0-847.1,0s-184.8-33.1-184.8-215.4s138.6-248.6,138.6-248.6
		S5520.9,1382,5621,1423.4z"/>
	<path class="clouds-white" d="M835.6,940.9c0,0,32.9-305.5,362-305.5s362,250.6,362,250.6s279.7-54.8,353.7,141
		c74,195.8-98.7,313.3-98.7,313.3s-98.7,39.2-238.6,39.2s-904.9,0-904.9,0s-197.4-31.3-197.4-203.6s148.1-235,148.1-235
		S728.7,901.7,835.6,940.9z"/>
	<path class="clouds-white" d="M3486.2,1813c0,0,31.2-319.2,342.8-319.2s342.8,261.9,342.8,261.9s264.9-57.3,335,147.3
		c70.1,204.6-93.5,327.4-93.5,327.4s-93.5,40.9-225.9,40.9c-132.4,0-857,0-857,0s-187-32.7-187-212.8s140.2-245.5,140.2-245.5
		S3384.9,1772.1,3486.2,1813z"/>
</g>
</symbol>

`;
